@@ -72,23 +72,20 @@ class LinkFacter(Facter):
             if not url:
                 continue
 
-            if not self.is_valid(url):
+            aux = self.normalize_url(url)
+            if not aux:
                 invalid_links.add(url)
                 continue
 
+            url = aux
+
             if self.looks_like_image(url):
                 continue
 
-            is_absolute = self.is_absolute(url)
-
             should_get = False
-            if not is_absolute:
-                url = self.rebase(url)
+            domain, domain_url = get_domain_from_url(url)
+            if domain in self.page_url:
                 should_get = True
-            else:
-                domain, domain_url = get_domain_from_url(url)
-                if domain in self.page_url:
-                    should_get = True
 
             if should_get and URL_RE.match(url):
                 num_links += 1
@@ -114,7 +111,6 @@ class LinkFacter(Facter):
 
     def handle_url_loaded(self, url, response):
         logging.debug('Got response (%s) from %s!' % (response.status_code, url))
-        self.reviewer.ping()
         self.review.facts['page.links']['value'].add(url)
         self.review.data['page.links'].add((url, response))
 
