@@ -36,8 +36,10 @@ class WorkerStateHandler(BaseHandler):
             worker.current_url = None
 
         else:
-            logging.warning('Invalid operation (not start nor complete) in worker %s.' % worker_uuid)
-            raise tornado.web.HTTPError(400, 'Invalid Operation', reason='Invalid Operation')
+            logging.warning('Invalid operation (not start nor complete) in worker %s (current url: %s).' % (
+                worker_uuid, worker.current_url
+            ))
+            #raise tornado.web.HTTPError(400, 'Invalid Operation', reason='Invalid Operation')
 
     def start_work(self, worker, url):
         lock = RedisLock(
