@@ -29,18 +29,22 @@ class LinkWithRelCanonicalValidator(Validator):
         if not self.config.FORCE_CANONICAL:
             # Only pages with query string parameters
             if self.page_url:
+                if not self.is_valid(self.page_url):
+                    return
+
                 if not urlparse(self.page_url).query:
                     return
 
         head = self.get_head()
-        canonical = [item for item in head if item.get('rel') == 'canonical']
+        if head:
+            canonical = [item for item in head if item.get('rel') == 'canonical']
 
-        if not canonical:
-            self.add_violation(
-                key='absent.meta.canonical',
-                value=None,
-                points=30
-            )
+            if not canonical:
+                self.add_violation(
+                    key='absent.meta.canonical',
+                    value=None,
+                    points=30
+                )
 
     def get_head(self):
         return self.review.data.get('page.head', None)
