@@ -120,7 +120,7 @@ class SitemapValidator(Validator):
                 if not encoded:
                     not_encoded_links += 1
 
-                self.send_url(response.effective_url, response)
+                self.send_url(response.effective_url, self.reviewer.page_score / float(urls_count), response)
 
             if not_encoded_links > 0:
                 self.add_violation(
